""" 
One line description.

A more detailed explanation.
"""


def convert(path):
    """ 
    Convert given pdf to text.

    Parameters:
    path (str): The path to a PDF file.

    Returns:
    str: The content of the PDF file as text.
    """
    print("pdf2text", path)
